@@ -77,8 +77,13 @@ def checkCores():
     if "Darwin" in str(operatingsystem):
         cores = int(check_output("sysctl -n hw.ncpu", shell=True)) * multiplier
     else:
-        cores = int(check_output(
-            "egrep 'cpu cores' /proc/cpuinfo | uniq | egrep -o '[0-9]'")) * multiplier
+        try:
+            with open('/proc/cpuinfo') as f:
+                coredata = f.read()
+            cores = coredata.count('Processor') * multiplier
+        except:
+            print('Cannot get cores info, defaulting to 4')
+            cores = 4
     return cores
 
 
